@@ -8,6 +8,7 @@ __author__ = "Jayaram Kancherla"
 __copyright__ = "jkanche"
 __license__ = "mit"
 
+
 class InteractionBigBed(BigBed):
     """
     BigBed file parser for chromosome interaction Data
@@ -18,23 +19,24 @@ class InteractionBigBed(BigBed):
         exp, color,
         region1chr, region1start, region1end, region1name, region1strand,
         region2chr, region2start, region2end, region2name, region2strand)
-    
+
     Args: 
         file (str): InteractionBigBed file location
     """
-    
+
     magic = "0x8789F2EB"
 
     def __init__(self, file, columns=["chr", "start", "end", "name", "score", "value",
-        "exp", "color",
-        "region1chr", "region1start", "region1end", "region1name", "region1strand",
-        "region2chr", "region2start", "region2end", "region2name", "region2strand"]):
+                                      "exp", "color",
+                                      "region1chr", "region1start", "region1end", "region1name", "region1strand",
+                                      "region2chr", "region2start", "region2end", "region2name", "region2strand"]):
         self.colFlag = False
         print("init interaction bigbed")
         super(InteractionBigBed, self).__init__(file, columns=columns)
         print(self.columns)
 
-    def getRange(self, chr, start, end, bins=2000, zoomlvl=-1, metric="AVG", respType = "DataFrame", treedisk=None):
-        result, _ = super(InteractionBigBed, self).getRange(chr, start, end, bins, zoomlvl = -2, metric=metric, respType=respType, treedisk=treedisk)
+    def getRange(self, chr, start, end, bins=2000, zoomlvl=-1, metric="AVG", respType="DataFrame", treedisk=None):
+        result, _ = super(InteractionBigBed, self).getRange(
+            chr, start, end, bins, zoomlvl=-2, metric=metric, respType=respType, treedisk=treedisk)
         print(result)
         return result, _
